# Moosetash

## A Mustache template renderer for Python

Moosetash is a python implementation of the [Mustache](https://mustache.github.io/) templating specification.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
